@@ -82,27 +82,6 @@ describe 'trove::keystone::auth' do
     ) }
   end
 
-  describe 'with deprecated endpoint parameters' do
-    let :params do
-      { :password          => 'trove_password',
-        :public_protocol   => 'https',
-        :public_port       => '80',
-        :public_address    => '10.10.10.10',
-        :port              => '81',
-        :internal_protocol => 'https',
-        :internal_address  => '10.10.10.11',
-        :admin_protocol    => 'https',
-        :admin_address     => '10.10.10.12' }
-    end
-
-    it { is_expected.to contain_keystone_endpoint('RegionOne/trove::database').with(
-      :ensure       => 'present',
-      :public_url   => 'https://10.10.10.10:80/v1.0/%(tenant_id)s',
-      :internal_url => 'https://10.10.10.11:81/v1.0/%(tenant_id)s',
-      :admin_url    => 'https://10.10.10.12:81/v1.0/%(tenant_id)s'
-    ) }
-  end
-
   describe 'when overriding auth name' do
     let :params do
       { :password => 'foo',
@@ -111,8 +90,8 @@ describe 'trove::keystone::auth' do
 
     it { is_expected.to contain_keystone_user('trovey') }
     it { is_expected.to contain_keystone_user_role('trovey@services') }
-    it { is_expected.to contain_keystone_service('trovey::database') }
-    it { is_expected.to contain_keystone_endpoint('RegionOne/trovey::database') }
+    it { is_expected.to contain_keystone_service('trove::database') }
+    it { is_expected.to contain_keystone_endpoint('RegionOne/trove::database') }
   end
 
   describe 'when overriding service name' do
@@ -136,4 +115,18 @@ describe 'trove::keystone::auth' do
 
     it { is_expected.to_not contain_keystone_endpoint('RegionOne/neutron::database') }
   end
+
+  describe 'when disabling user and user_role configuration' do
+    let :params do
+      { :configure_user      => false,
+        :configure_user_role => false,
+        :service_name => 'trove',
+        :auth_name    => 'trove',
+        :password            => 'trove_password' }
+    end
+    it { is_expected.to_not contain_keystone_user('trove') }
+    it { is_expected.to_not contain_keystone_user_role('trove@services') }
+    it { is_expected.to contain_keystone_service('trove::database') }
+    it { is_expected.to contain_keystone_endpoint('RegionOne/trove::database') }
+  end
 end
